@@ -7,11 +7,11 @@ from poetry.utils._compat import urlparse
 
 class Auth(AuthBase):
     def __init__(self, url, username, password):  # type: (str, str, str) -> None
-        self._netloc = urlparse.urlparse(url).netloc
+        self._hostname = urlparse.urlparse(url).hostname
         self._auth = HTTPBasicAuth(username, password)
 
     def __call__(self, r):  # type: (Request) -> Request
-        if urlparse.urlparse(r.url).netloc != self._netloc:
+        if urlparse.urlparse(r.url).hostname != self._hostname:
             return r
 
         self._auth(r)
